// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.7
// 	protoc        v6.30.2
// source: spire/api/server/localauthority/v1/localauthority.proto

package localauthorityv1

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetJWTAuthorityStateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetJWTAuthorityStateRequest) Reset() {
	*x = GetJWTAuthorityStateRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetJWTAuthorityStateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetJWTAuthorityStateRequest) ProtoMessage() {}

func (x *GetJWTAuthorityStateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetJWTAuthorityStateRequest.ProtoReflect.Descriptor instead.
func (*GetJWTAuthorityStateRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{0}
}

type GetJWTAuthorityStateResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Authority currently being used for signing operations.
	Active *AuthorityState `protobuf:"bytes,1,opt,name=active,proto3" json:"active,omitempty"`
	// Authority added on bundle but is not used yet.
	Prepared *AuthorityState `protobuf:"bytes,2,opt,name=prepared,proto3" json:"prepared,omitempty"`
	// Authority in that was previously used for signing operations,
	// but it is not longer.
	Old           *AuthorityState `protobuf:"bytes,3,opt,name=old,proto3" json:"old,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetJWTAuthorityStateResponse) Reset() {
	*x = GetJWTAuthorityStateResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetJWTAuthorityStateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetJWTAuthorityStateResponse) ProtoMessage() {}

func (x *GetJWTAuthorityStateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetJWTAuthorityStateResponse.ProtoReflect.Descriptor instead.
func (*GetJWTAuthorityStateResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{1}
}

func (x *GetJWTAuthorityStateResponse) GetActive() *AuthorityState {
	if x != nil {
		return x.Active
	}
	return nil
}

func (x *GetJWTAuthorityStateResponse) GetPrepared() *AuthorityState {
	if x != nil {
		return x.Prepared
	}
	return nil
}

func (x *GetJWTAuthorityStateResponse) GetOld() *AuthorityState {
	if x != nil {
		return x.Old
	}
	return nil
}

type PrepareJWTAuthorityRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PrepareJWTAuthorityRequest) Reset() {
	*x = PrepareJWTAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareJWTAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareJWTAuthorityRequest) ProtoMessage() {}

func (x *PrepareJWTAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareJWTAuthorityRequest.ProtoReflect.Descriptor instead.
func (*PrepareJWTAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{2}
}

type PrepareJWTAuthorityResponse struct {
	state             protoimpl.MessageState `protogen:"open.v1"`
	PreparedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=prepared_authority,json=preparedAuthority,proto3" json:"prepared_authority,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *PrepareJWTAuthorityResponse) Reset() {
	*x = PrepareJWTAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareJWTAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareJWTAuthorityResponse) ProtoMessage() {}

func (x *PrepareJWTAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareJWTAuthorityResponse.ProtoReflect.Descriptor instead.
func (*PrepareJWTAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{3}
}

func (x *PrepareJWTAuthorityResponse) GetPreparedAuthority() *AuthorityState {
	if x != nil {
		return x.PreparedAuthority
	}
	return nil
}

type ActivateJWTAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority JWT authority to activate.
	// This is the JWT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ActivateJWTAuthorityRequest) Reset() {
	*x = ActivateJWTAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateJWTAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateJWTAuthorityRequest) ProtoMessage() {}

func (x *ActivateJWTAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateJWTAuthorityRequest.ProtoReflect.Descriptor instead.
func (*ActivateJWTAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{4}
}

func (x *ActivateJWTAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type ActivateJWTAuthorityResponse struct {
	state              protoimpl.MessageState `protogen:"open.v1"`
	ActivatedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=activated_authority,json=activatedAuthority,proto3" json:"activated_authority,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *ActivateJWTAuthorityResponse) Reset() {
	*x = ActivateJWTAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateJWTAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateJWTAuthorityResponse) ProtoMessage() {}

func (x *ActivateJWTAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateJWTAuthorityResponse.ProtoReflect.Descriptor instead.
func (*ActivateJWTAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{5}
}

func (x *ActivateJWTAuthorityResponse) GetActivatedAuthority() *AuthorityState {
	if x != nil {
		return x.ActivatedAuthority
	}
	return nil
}

type TaintJWTAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority JWT authority to taint.
	// This is the JWT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *TaintJWTAuthorityRequest) Reset() {
	*x = TaintJWTAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintJWTAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintJWTAuthorityRequest) ProtoMessage() {}

func (x *TaintJWTAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintJWTAuthorityRequest.ProtoReflect.Descriptor instead.
func (*TaintJWTAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{6}
}

func (x *TaintJWTAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type TaintJWTAuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	TaintedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=tainted_authority,json=taintedAuthority,proto3" json:"tainted_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *TaintJWTAuthorityResponse) Reset() {
	*x = TaintJWTAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintJWTAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintJWTAuthorityResponse) ProtoMessage() {}

func (x *TaintJWTAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintJWTAuthorityResponse.ProtoReflect.Descriptor instead.
func (*TaintJWTAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{7}
}

func (x *TaintJWTAuthorityResponse) GetTaintedAuthority() *AuthorityState {
	if x != nil {
		return x.TaintedAuthority
	}
	return nil
}

type RevokeJWTAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority JWT authority to revoke.
	// This is the JWT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeJWTAuthorityRequest) Reset() {
	*x = RevokeJWTAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeJWTAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeJWTAuthorityRequest) ProtoMessage() {}

func (x *RevokeJWTAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeJWTAuthorityRequest.ProtoReflect.Descriptor instead.
func (*RevokeJWTAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{8}
}

func (x *RevokeJWTAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type RevokeJWTAuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	RevokedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=revoked_authority,json=revokedAuthority,proto3" json:"revoked_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *RevokeJWTAuthorityResponse) Reset() {
	*x = RevokeJWTAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeJWTAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeJWTAuthorityResponse) ProtoMessage() {}

func (x *RevokeJWTAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeJWTAuthorityResponse.ProtoReflect.Descriptor instead.
func (*RevokeJWTAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{9}
}

func (x *RevokeJWTAuthorityResponse) GetRevokedAuthority() *AuthorityState {
	if x != nil {
		return x.RevokedAuthority
	}
	return nil
}

type GetX509AuthorityStateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetX509AuthorityStateRequest) Reset() {
	*x = GetX509AuthorityStateRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetX509AuthorityStateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetX509AuthorityStateRequest) ProtoMessage() {}

func (x *GetX509AuthorityStateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetX509AuthorityStateRequest.ProtoReflect.Descriptor instead.
func (*GetX509AuthorityStateRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{10}
}

type GetX509AuthorityStateResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Authority currently being used for signing operations.
	Active *AuthorityState `protobuf:"bytes,1,opt,name=active,proto3" json:"active,omitempty"`
	// Authority added on bundle but is not used yet.
	Prepared *AuthorityState `protobuf:"bytes,2,opt,name=prepared,proto3" json:"prepared,omitempty"`
	// Authority in that was previously used for signing operations,
	// but it is not longer.
	Old           *AuthorityState `protobuf:"bytes,3,opt,name=old,proto3" json:"old,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetX509AuthorityStateResponse) Reset() {
	*x = GetX509AuthorityStateResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetX509AuthorityStateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetX509AuthorityStateResponse) ProtoMessage() {}

func (x *GetX509AuthorityStateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetX509AuthorityStateResponse.ProtoReflect.Descriptor instead.
func (*GetX509AuthorityStateResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{11}
}

func (x *GetX509AuthorityStateResponse) GetActive() *AuthorityState {
	if x != nil {
		return x.Active
	}
	return nil
}

func (x *GetX509AuthorityStateResponse) GetPrepared() *AuthorityState {
	if x != nil {
		return x.Prepared
	}
	return nil
}

func (x *GetX509AuthorityStateResponse) GetOld() *AuthorityState {
	if x != nil {
		return x.Old
	}
	return nil
}

type PrepareX509AuthorityRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PrepareX509AuthorityRequest) Reset() {
	*x = PrepareX509AuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareX509AuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareX509AuthorityRequest) ProtoMessage() {}

func (x *PrepareX509AuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareX509AuthorityRequest.ProtoReflect.Descriptor instead.
func (*PrepareX509AuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{12}
}

type PrepareX509AuthorityResponse struct {
	state             protoimpl.MessageState `protogen:"open.v1"`
	PreparedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=prepared_authority,json=preparedAuthority,proto3" json:"prepared_authority,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *PrepareX509AuthorityResponse) Reset() {
	*x = PrepareX509AuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareX509AuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareX509AuthorityResponse) ProtoMessage() {}

func (x *PrepareX509AuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareX509AuthorityResponse.ProtoReflect.Descriptor instead.
func (*PrepareX509AuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{13}
}

func (x *PrepareX509AuthorityResponse) GetPreparedAuthority() *AuthorityState {
	if x != nil {
		return x.PreparedAuthority
	}
	return nil
}

type ActivateX509AuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local X.509 authority to activate.
	// This is the X.509 Subject Key Identifier (or SKID) of the
	// authority's CA certificate, which is calculated by doing a
	// SHA-1 hash over the ASN.1 encoding of the public key.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ActivateX509AuthorityRequest) Reset() {
	*x = ActivateX509AuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateX509AuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateX509AuthorityRequest) ProtoMessage() {}

func (x *ActivateX509AuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateX509AuthorityRequest.ProtoReflect.Descriptor instead.
func (*ActivateX509AuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{14}
}

func (x *ActivateX509AuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type ActivateX509AuthorityResponse struct {
	state              protoimpl.MessageState `protogen:"open.v1"`
	ActivatedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=activated_authority,json=activatedAuthority,proto3" json:"activated_authority,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *ActivateX509AuthorityResponse) Reset() {
	*x = ActivateX509AuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateX509AuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateX509AuthorityResponse) ProtoMessage() {}

func (x *ActivateX509AuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateX509AuthorityResponse.ProtoReflect.Descriptor instead.
func (*ActivateX509AuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{15}
}

func (x *ActivateX509AuthorityResponse) GetActivatedAuthority() *AuthorityState {
	if x != nil {
		return x.ActivatedAuthority
	}
	return nil
}

type TaintX509AuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local X.509 authority to taint.
	// This is the X.509 Subject Key Identifier (or SKID) of the
	// authority's CA certificate, which is calculated by doing a
	// SHA-1 hash over the ASN.1 encoding of the public key.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *TaintX509AuthorityRequest) Reset() {
	*x = TaintX509AuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintX509AuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintX509AuthorityRequest) ProtoMessage() {}

func (x *TaintX509AuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintX509AuthorityRequest.ProtoReflect.Descriptor instead.
func (*TaintX509AuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{16}
}

func (x *TaintX509AuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type TaintX509AuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	TaintedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=tainted_authority,json=taintedAuthority,proto3" json:"tainted_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *TaintX509AuthorityResponse) Reset() {
	*x = TaintX509AuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintX509AuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintX509AuthorityResponse) ProtoMessage() {}

func (x *TaintX509AuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintX509AuthorityResponse.ProtoReflect.Descriptor instead.
func (*TaintX509AuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{17}
}

func (x *TaintX509AuthorityResponse) GetTaintedAuthority() *AuthorityState {
	if x != nil {
		return x.TaintedAuthority
	}
	return nil
}

type TaintX509UpstreamAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// This is the X.509 Subject Key Identifier (or SKID) of the
	// authority's CA certificate of the upstream X.509 authority to taint.
	SubjectKeyId  string `protobuf:"bytes,1,opt,name=subject_key_id,json=subjectKeyId,proto3" json:"subject_key_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *TaintX509UpstreamAuthorityRequest) Reset() {
	*x = TaintX509UpstreamAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintX509UpstreamAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintX509UpstreamAuthorityRequest) ProtoMessage() {}

func (x *TaintX509UpstreamAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintX509UpstreamAuthorityRequest.ProtoReflect.Descriptor instead.
func (*TaintX509UpstreamAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{18}
}

func (x *TaintX509UpstreamAuthorityRequest) GetSubjectKeyId() string {
	if x != nil {
		return x.SubjectKeyId
	}
	return ""
}

type TaintX509UpstreamAuthorityResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The Subject Key Identifier (or SKID) of the upstream authority
	// tainted.
	UpstreamAuthoritySubjectKeyId string `protobuf:"bytes,1,opt,name=upstream_authority_subject_key_id,json=upstreamAuthoritySubjectKeyId,proto3" json:"upstream_authority_subject_key_id,omitempty"`
	unknownFields                 protoimpl.UnknownFields
	sizeCache                     protoimpl.SizeCache
}

func (x *TaintX509UpstreamAuthorityResponse) Reset() {
	*x = TaintX509UpstreamAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintX509UpstreamAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintX509UpstreamAuthorityResponse) ProtoMessage() {}

func (x *TaintX509UpstreamAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintX509UpstreamAuthorityResponse.ProtoReflect.Descriptor instead.
func (*TaintX509UpstreamAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{19}
}

func (x *TaintX509UpstreamAuthorityResponse) GetUpstreamAuthoritySubjectKeyId() string {
	if x != nil {
		return x.UpstreamAuthoritySubjectKeyId
	}
	return ""
}

type RevokeX509UpstreamAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// This is the X.509 Subject Key Identifier (or SKID) of the
	// authority's CA certificate of the upstream X.509 authority to revoke.
	SubjectKeyId  string `protobuf:"bytes,1,opt,name=subject_key_id,json=subjectKeyId,proto3" json:"subject_key_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeX509UpstreamAuthorityRequest) Reset() {
	*x = RevokeX509UpstreamAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeX509UpstreamAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeX509UpstreamAuthorityRequest) ProtoMessage() {}

func (x *RevokeX509UpstreamAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeX509UpstreamAuthorityRequest.ProtoReflect.Descriptor instead.
func (*RevokeX509UpstreamAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{20}
}

func (x *RevokeX509UpstreamAuthorityRequest) GetSubjectKeyId() string {
	if x != nil {
		return x.SubjectKeyId
	}
	return ""
}

type RevokeX509UpstreamAuthorityResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The Subject Key Identifier (or SKID) of the upstream authority
	// revoked.
	UpstreamAuthoritySubjectKeyId string `protobuf:"bytes,1,opt,name=upstream_authority_subject_key_id,json=upstreamAuthoritySubjectKeyId,proto3" json:"upstream_authority_subject_key_id,omitempty"`
	unknownFields                 protoimpl.UnknownFields
	sizeCache                     protoimpl.SizeCache
}

func (x *RevokeX509UpstreamAuthorityResponse) Reset() {
	*x = RevokeX509UpstreamAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeX509UpstreamAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeX509UpstreamAuthorityResponse) ProtoMessage() {}

func (x *RevokeX509UpstreamAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeX509UpstreamAuthorityResponse.ProtoReflect.Descriptor instead.
func (*RevokeX509UpstreamAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{21}
}

func (x *RevokeX509UpstreamAuthorityResponse) GetUpstreamAuthoritySubjectKeyId() string {
	if x != nil {
		return x.UpstreamAuthoritySubjectKeyId
	}
	return ""
}

type RevokeX509AuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local X.509 authority to revoke.
	// This is the X.509 Subject Key Identifier (or SKID) of the
	// authority's CA certificate, which is calculated by doing a
	// SHA-1 hash over the ASN.1 encoding of the public key.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeX509AuthorityRequest) Reset() {
	*x = RevokeX509AuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeX509AuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeX509AuthorityRequest) ProtoMessage() {}

func (x *RevokeX509AuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeX509AuthorityRequest.ProtoReflect.Descriptor instead.
func (*RevokeX509AuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{22}
}

func (x *RevokeX509AuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type RevokeX509AuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	RevokedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=revoked_authority,json=revokedAuthority,proto3" json:"revoked_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *RevokeX509AuthorityResponse) Reset() {
	*x = RevokeX509AuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeX509AuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeX509AuthorityResponse) ProtoMessage() {}

func (x *RevokeX509AuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeX509AuthorityResponse.ProtoReflect.Descriptor instead.
func (*RevokeX509AuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{23}
}

func (x *RevokeX509AuthorityResponse) GetRevokedAuthority() *AuthorityState {
	if x != nil {
		return x.RevokedAuthority
	}
	return nil
}

type GetWITAuthorityStateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetWITAuthorityStateRequest) Reset() {
	*x = GetWITAuthorityStateRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetWITAuthorityStateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetWITAuthorityStateRequest) ProtoMessage() {}

func (x *GetWITAuthorityStateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetWITAuthorityStateRequest.ProtoReflect.Descriptor instead.
func (*GetWITAuthorityStateRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{24}
}

type GetWITAuthorityStateResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Authority currently being used for signing operations.
	Active *AuthorityState `protobuf:"bytes,1,opt,name=active,proto3" json:"active,omitempty"`
	// Authority added on bundle but is not used yet.
	Prepared *AuthorityState `protobuf:"bytes,2,opt,name=prepared,proto3" json:"prepared,omitempty"`
	// Authority in that was previously used for signing operations,
	// but it is not longer.
	Old           *AuthorityState `protobuf:"bytes,3,opt,name=old,proto3" json:"old,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetWITAuthorityStateResponse) Reset() {
	*x = GetWITAuthorityStateResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetWITAuthorityStateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetWITAuthorityStateResponse) ProtoMessage() {}

func (x *GetWITAuthorityStateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetWITAuthorityStateResponse.ProtoReflect.Descriptor instead.
func (*GetWITAuthorityStateResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{25}
}

func (x *GetWITAuthorityStateResponse) GetActive() *AuthorityState {
	if x != nil {
		return x.Active
	}
	return nil
}

func (x *GetWITAuthorityStateResponse) GetPrepared() *AuthorityState {
	if x != nil {
		return x.Prepared
	}
	return nil
}

func (x *GetWITAuthorityStateResponse) GetOld() *AuthorityState {
	if x != nil {
		return x.Old
	}
	return nil
}

type PrepareWITAuthorityRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PrepareWITAuthorityRequest) Reset() {
	*x = PrepareWITAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareWITAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareWITAuthorityRequest) ProtoMessage() {}

func (x *PrepareWITAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareWITAuthorityRequest.ProtoReflect.Descriptor instead.
func (*PrepareWITAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{26}
}

type PrepareWITAuthorityResponse struct {
	state             protoimpl.MessageState `protogen:"open.v1"`
	PreparedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=prepared_authority,json=preparedAuthority,proto3" json:"prepared_authority,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *PrepareWITAuthorityResponse) Reset() {
	*x = PrepareWITAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PrepareWITAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PrepareWITAuthorityResponse) ProtoMessage() {}

func (x *PrepareWITAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PrepareWITAuthorityResponse.ProtoReflect.Descriptor instead.
func (*PrepareWITAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{27}
}

func (x *PrepareWITAuthorityResponse) GetPreparedAuthority() *AuthorityState {
	if x != nil {
		return x.PreparedAuthority
	}
	return nil
}

type ActivateWITAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority WIT authority to activate.
	// This is the WIT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ActivateWITAuthorityRequest) Reset() {
	*x = ActivateWITAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateWITAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateWITAuthorityRequest) ProtoMessage() {}

func (x *ActivateWITAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateWITAuthorityRequest.ProtoReflect.Descriptor instead.
func (*ActivateWITAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{28}
}

func (x *ActivateWITAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type ActivateWITAuthorityResponse struct {
	state              protoimpl.MessageState `protogen:"open.v1"`
	ActivatedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=activated_authority,json=activatedAuthority,proto3" json:"activated_authority,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *ActivateWITAuthorityResponse) Reset() {
	*x = ActivateWITAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActivateWITAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActivateWITAuthorityResponse) ProtoMessage() {}

func (x *ActivateWITAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActivateWITAuthorityResponse.ProtoReflect.Descriptor instead.
func (*ActivateWITAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{29}
}

func (x *ActivateWITAuthorityResponse) GetActivatedAuthority() *AuthorityState {
	if x != nil {
		return x.ActivatedAuthority
	}
	return nil
}

type TaintWITAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority WIT authority to taint.
	// This is the WIT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *TaintWITAuthorityRequest) Reset() {
	*x = TaintWITAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintWITAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintWITAuthorityRequest) ProtoMessage() {}

func (x *TaintWITAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintWITAuthorityRequest.ProtoReflect.Descriptor instead.
func (*TaintWITAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{30}
}

func (x *TaintWITAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type TaintWITAuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	TaintedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=tainted_authority,json=taintedAuthority,proto3" json:"tainted_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *TaintWITAuthorityResponse) Reset() {
	*x = TaintWITAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *TaintWITAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaintWITAuthorityResponse) ProtoMessage() {}

func (x *TaintWITAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaintWITAuthorityResponse.ProtoReflect.Descriptor instead.
func (*TaintWITAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{31}
}

func (x *TaintWITAuthorityResponse) GetTaintedAuthority() *AuthorityState {
	if x != nil {
		return x.TaintedAuthority
	}
	return nil
}

type RevokeWITAuthorityRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID of the local authority WIT authority to revoke.
	// This is the WIT Key ID.
	AuthorityId   string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeWITAuthorityRequest) Reset() {
	*x = RevokeWITAuthorityRequest{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeWITAuthorityRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeWITAuthorityRequest) ProtoMessage() {}

func (x *RevokeWITAuthorityRequest) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeWITAuthorityRequest.ProtoReflect.Descriptor instead.
func (*RevokeWITAuthorityRequest) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{32}
}

func (x *RevokeWITAuthorityRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type RevokeWITAuthorityResponse struct {
	state            protoimpl.MessageState `protogen:"open.v1"`
	RevokedAuthority *AuthorityState        `protobuf:"bytes,1,opt,name=revoked_authority,json=revokedAuthority,proto3" json:"revoked_authority,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *RevokeWITAuthorityResponse) Reset() {
	*x = RevokeWITAuthorityResponse{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeWITAuthorityResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeWITAuthorityResponse) ProtoMessage() {}

func (x *RevokeWITAuthorityResponse) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeWITAuthorityResponse.ProtoReflect.Descriptor instead.
func (*RevokeWITAuthorityResponse) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{33}
}

func (x *RevokeWITAuthorityResponse) GetRevokedAuthority() *AuthorityState {
	if x != nil {
		return x.RevokedAuthority
	}
	return nil
}

type AuthorityState struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The authority ID.
	AuthorityId string `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	// Expiration timestamp (seconds since Unix epoch).
	ExpiresAt int64 `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// The Subject Key Identifier (or SKID) of the upstream authority,
	// applicable only for X.509 authorities.
	UpstreamAuthoritySubjectKeyId string `protobuf:"bytes,3,opt,name=upstream_authority_subject_key_id,json=upstreamAuthoritySubjectKeyId,proto3" json:"upstream_authority_subject_key_id,omitempty"`
	unknownFields                 protoimpl.UnknownFields
	sizeCache                     protoimpl.SizeCache
}

func (x *AuthorityState) Reset() {
	*x = AuthorityState{}
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AuthorityState) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AuthorityState) ProtoMessage() {}

func (x *AuthorityState) ProtoReflect() protoreflect.Message {
	mi := &file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AuthorityState.ProtoReflect.Descriptor instead.
func (*AuthorityState) Descriptor() ([]byte, []int) {
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP(), []int{34}
}

func (x *AuthorityState) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

func (x *AuthorityState) GetExpiresAt() int64 {
	if x != nil {
		return x.ExpiresAt
	}
	return 0
}

func (x *AuthorityState) GetUpstreamAuthoritySubjectKeyId() string {
	if x != nil {
		return x.UpstreamAuthoritySubjectKeyId
	}
	return ""
}

var File_spire_api_server_localauthority_v1_localauthority_proto protoreflect.FileDescriptor

const file_spire_api_server_localauthority_v1_localauthority_proto_rawDesc = "" +
	"\n" +
	"7spire/api/server/localauthority/v1/localauthority.proto\x12\"spire.api.server.localauthority.v1\"\x1d\n" +
	"\x1bGetJWTAuthorityStateRequest\"\x80\x02\n" +
	"\x1cGetJWTAuthorityStateResponse\x12J\n" +
	"\x06active\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x06active\x12N\n" +
	"\bprepared\x18\x02 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\bprepared\x12D\n" +
	"\x03old\x18\x03 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x03old\"\x1c\n" +
	"\x1aPrepareJWTAuthorityRequest\"\x80\x01\n" +
	"\x1bPrepareJWTAuthorityResponse\x12a\n" +
	"\x12prepared_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x11preparedAuthority\"@\n" +
	"\x1bActivateJWTAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"\x83\x01\n" +
	"\x1cActivateJWTAuthorityResponse\x12c\n" +
	"\x13activated_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x12activatedAuthority\"=\n" +
	"\x18TaintJWTAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"|\n" +
	"\x19TaintJWTAuthorityResponse\x12_\n" +
	"\x11tainted_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10taintedAuthority\">\n" +
	"\x19RevokeJWTAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"}\n" +
	"\x1aRevokeJWTAuthorityResponse\x12_\n" +
	"\x11revoked_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10revokedAuthority\"\x1e\n" +
	"\x1cGetX509AuthorityStateRequest\"\x81\x02\n" +
	"\x1dGetX509AuthorityStateResponse\x12J\n" +
	"\x06active\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x06active\x12N\n" +
	"\bprepared\x18\x02 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\bprepared\x12D\n" +
	"\x03old\x18\x03 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x03old\"\x1d\n" +
	"\x1bPrepareX509AuthorityRequest\"\x81\x01\n" +
	"\x1cPrepareX509AuthorityResponse\x12a\n" +
	"\x12prepared_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x11preparedAuthority\"A\n" +
	"\x1cActivateX509AuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"\x84\x01\n" +
	"\x1dActivateX509AuthorityResponse\x12c\n" +
	"\x13activated_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x12activatedAuthority\">\n" +
	"\x19TaintX509AuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"}\n" +
	"\x1aTaintX509AuthorityResponse\x12_\n" +
	"\x11tainted_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10taintedAuthority\"I\n" +
	"!TaintX509UpstreamAuthorityRequest\x12$\n" +
	"\x0esubject_key_id\x18\x01 \x01(\tR\fsubjectKeyId\"n\n" +
	"\"TaintX509UpstreamAuthorityResponse\x12H\n" +
	"!upstream_authority_subject_key_id\x18\x01 \x01(\tR\x1dupstreamAuthoritySubjectKeyId\"J\n" +
	"\"RevokeX509UpstreamAuthorityRequest\x12$\n" +
	"\x0esubject_key_id\x18\x01 \x01(\tR\fsubjectKeyId\"o\n" +
	"#RevokeX509UpstreamAuthorityResponse\x12H\n" +
	"!upstream_authority_subject_key_id\x18\x01 \x01(\tR\x1dupstreamAuthoritySubjectKeyId\"?\n" +
	"\x1aRevokeX509AuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"~\n" +
	"\x1bRevokeX509AuthorityResponse\x12_\n" +
	"\x11revoked_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10revokedAuthority\"\x1d\n" +
	"\x1bGetWITAuthorityStateRequest\"\x80\x02\n" +
	"\x1cGetWITAuthorityStateResponse\x12J\n" +
	"\x06active\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x06active\x12N\n" +
	"\bprepared\x18\x02 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\bprepared\x12D\n" +
	"\x03old\x18\x03 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x03old\"\x1c\n" +
	"\x1aPrepareWITAuthorityRequest\"\x80\x01\n" +
	"\x1bPrepareWITAuthorityResponse\x12a\n" +
	"\x12prepared_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x11preparedAuthority\"@\n" +
	"\x1bActivateWITAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"\x83\x01\n" +
	"\x1cActivateWITAuthorityResponse\x12c\n" +
	"\x13activated_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x12activatedAuthority\"=\n" +
	"\x18TaintWITAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"|\n" +
	"\x19TaintWITAuthorityResponse\x12_\n" +
	"\x11tainted_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10taintedAuthority\">\n" +
	"\x19RevokeWITAuthorityRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"}\n" +
	"\x1aRevokeWITAuthorityResponse\x12_\n" +
	"\x11revoked_authority\x18\x01 \x01(\v22.spire.api.server.localauthority.v1.AuthorityStateR\x10revokedAuthority\"\x9c\x01\n" +
	"\x0eAuthorityState\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\x12\x1d\n" +
	"\n" +
	"expires_at\x18\x02 \x01(\x03R\texpiresAt\x12H\n" +
	"!upstream_authority_subject_key_id\x18\x03 \x01(\tR\x1dupstreamAuthoritySubjectKeyId2\xec\x14\n" +
	"\x0eLocalAuthority\x12\x99\x01\n" +
	"\x14GetJWTAuthorityState\x12?.spire.api.server.localauthority.v1.GetJWTAuthorityStateRequest\x1a@.spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse\x12\x96\x01\n" +
	"\x13PrepareJWTAuthority\x12>.spire.api.server.localauthority.v1.PrepareJWTAuthorityRequest\x1a?.spire.api.server.localauthority.v1.PrepareJWTAuthorityResponse\x12\x99\x01\n" +
	"\x14ActivateJWTAuthority\x12?.spire.api.server.localauthority.v1.ActivateJWTAuthorityRequest\x1a@.spire.api.server.localauthority.v1.ActivateJWTAuthorityResponse\x12\x90\x01\n" +
	"\x11TaintJWTAuthority\x12<.spire.api.server.localauthority.v1.TaintJWTAuthorityRequest\x1a=.spire.api.server.localauthority.v1.TaintJWTAuthorityResponse\x12\x93\x01\n" +
	"\x12RevokeJWTAuthority\x12=.spire.api.server.localauthority.v1.RevokeJWTAuthorityRequest\x1a>.spire.api.server.localauthority.v1.RevokeJWTAuthorityResponse\x12\x9c\x01\n" +
	"\x15GetX509AuthorityState\x12@.spire.api.server.localauthority.v1.GetX509AuthorityStateRequest\x1aA.spire.api.server.localauthority.v1.GetX509AuthorityStateResponse\x12\x99\x01\n" +
	"\x14PrepareX509Authority\x12?.spire.api.server.localauthority.v1.PrepareX509AuthorityRequest\x1a@.spire.api.server.localauthority.v1.PrepareX509AuthorityResponse\x12\x9c\x01\n" +
	"\x15ActivateX509Authority\x12@.spire.api.server.localauthority.v1.ActivateX509AuthorityRequest\x1aA.spire.api.server.localauthority.v1.ActivateX509AuthorityResponse\x12\x93\x01\n" +
	"\x12TaintX509Authority\x12=.spire.api.server.localauthority.v1.TaintX509AuthorityRequest\x1a>.spire.api.server.localauthority.v1.TaintX509AuthorityResponse\x12\xab\x01\n" +
	"\x1aTaintX509UpstreamAuthority\x12E.spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityRequest\x1aF.spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityResponse\x12\x96\x01\n" +
	"\x13RevokeX509Authority\x12>.spire.api.server.localauthority.v1.RevokeX509AuthorityRequest\x1a?.spire.api.server.localauthority.v1.RevokeX509AuthorityResponse\x12\xae\x01\n" +
	"\x1bRevokeX509UpstreamAuthority\x12F.spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityRequest\x1aG.spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityResponse\x12\x99\x01\n" +
	"\x14GetWITAuthorityState\x12?.spire.api.server.localauthority.v1.GetWITAuthorityStateRequest\x1a@.spire.api.server.localauthority.v1.GetWITAuthorityStateResponse\x12\x96\x01\n" +
	"\x13PrepareWITAuthority\x12>.spire.api.server.localauthority.v1.PrepareWITAuthorityRequest\x1a?.spire.api.server.localauthority.v1.PrepareWITAuthorityResponse\x12\x99\x01\n" +
	"\x14ActivateWITAuthority\x12?.spire.api.server.localauthority.v1.ActivateWITAuthorityRequest\x1a@.spire.api.server.localauthority.v1.ActivateWITAuthorityResponse\x12\x90\x01\n" +
	"\x11TaintWITAuthority\x12<.spire.api.server.localauthority.v1.TaintWITAuthorityRequest\x1a=.spire.api.server.localauthority.v1.TaintWITAuthorityResponse\x12\x93\x01\n" +
	"\x12RevokeWITAuthority\x12=.spire.api.server.localauthority.v1.RevokeWITAuthorityRequest\x1a>.spire.api.server.localauthority.v1.RevokeWITAuthorityResponseB[ZYgithub.com/spiffe/spire-api-sdk/proto/spire/api/server/localauthority/v1;localauthorityv1b\x06proto3"

var (
	file_spire_api_server_localauthority_v1_localauthority_proto_rawDescOnce sync.Once
	file_spire_api_server_localauthority_v1_localauthority_proto_rawDescData []byte
)

func file_spire_api_server_localauthority_v1_localauthority_proto_rawDescGZIP() []byte {
	file_spire_api_server_localauthority_v1_localauthority_proto_rawDescOnce.Do(func() {
		file_spire_api_server_localauthority_v1_localauthority_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_spire_api_server_localauthority_v1_localauthority_proto_rawDesc), len(file_spire_api_server_localauthority_v1_localauthority_proto_rawDesc)))
	})
	return file_spire_api_server_localauthority_v1_localauthority_proto_rawDescData
}

var file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes = make([]protoimpl.MessageInfo, 35)
var file_spire_api_server_localauthority_v1_localauthority_proto_goTypes = []any{
	(*GetJWTAuthorityStateRequest)(nil),         // 0: spire.api.server.localauthority.v1.GetJWTAuthorityStateRequest
	(*GetJWTAuthorityStateResponse)(nil),        // 1: spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse
	(*PrepareJWTAuthorityRequest)(nil),          // 2: spire.api.server.localauthority.v1.PrepareJWTAuthorityRequest
	(*PrepareJWTAuthorityResponse)(nil),         // 3: spire.api.server.localauthority.v1.PrepareJWTAuthorityResponse
	(*ActivateJWTAuthorityRequest)(nil),         // 4: spire.api.server.localauthority.v1.ActivateJWTAuthorityRequest
	(*ActivateJWTAuthorityResponse)(nil),        // 5: spire.api.server.localauthority.v1.ActivateJWTAuthorityResponse
	(*TaintJWTAuthorityRequest)(nil),            // 6: spire.api.server.localauthority.v1.TaintJWTAuthorityRequest
	(*TaintJWTAuthorityResponse)(nil),           // 7: spire.api.server.localauthority.v1.TaintJWTAuthorityResponse
	(*RevokeJWTAuthorityRequest)(nil),           // 8: spire.api.server.localauthority.v1.RevokeJWTAuthorityRequest
	(*RevokeJWTAuthorityResponse)(nil),          // 9: spire.api.server.localauthority.v1.RevokeJWTAuthorityResponse
	(*GetX509AuthorityStateRequest)(nil),        // 10: spire.api.server.localauthority.v1.GetX509AuthorityStateRequest
	(*GetX509AuthorityStateResponse)(nil),       // 11: spire.api.server.localauthority.v1.GetX509AuthorityStateResponse
	(*PrepareX509AuthorityRequest)(nil),         // 12: spire.api.server.localauthority.v1.PrepareX509AuthorityRequest
	(*PrepareX509AuthorityResponse)(nil),        // 13: spire.api.server.localauthority.v1.PrepareX509AuthorityResponse
	(*ActivateX509AuthorityRequest)(nil),        // 14: spire.api.server.localauthority.v1.ActivateX509AuthorityRequest
	(*ActivateX509AuthorityResponse)(nil),       // 15: spire.api.server.localauthority.v1.ActivateX509AuthorityResponse
	(*TaintX509AuthorityRequest)(nil),           // 16: spire.api.server.localauthority.v1.TaintX509AuthorityRequest
	(*TaintX509AuthorityResponse)(nil),          // 17: spire.api.server.localauthority.v1.TaintX509AuthorityResponse
	(*TaintX509UpstreamAuthorityRequest)(nil),   // 18: spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityRequest
	(*TaintX509UpstreamAuthorityResponse)(nil),  // 19: spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityResponse
	(*RevokeX509UpstreamAuthorityRequest)(nil),  // 20: spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityRequest
	(*RevokeX509UpstreamAuthorityResponse)(nil), // 21: spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityResponse
	(*RevokeX509AuthorityRequest)(nil),          // 22: spire.api.server.localauthority.v1.RevokeX509AuthorityRequest
	(*RevokeX509AuthorityResponse)(nil),         // 23: spire.api.server.localauthority.v1.RevokeX509AuthorityResponse
	(*GetWITAuthorityStateRequest)(nil),         // 24: spire.api.server.localauthority.v1.GetWITAuthorityStateRequest
	(*GetWITAuthorityStateResponse)(nil),        // 25: spire.api.server.localauthority.v1.GetWITAuthorityStateResponse
	(*PrepareWITAuthorityRequest)(nil),          // 26: spire.api.server.localauthority.v1.PrepareWITAuthorityRequest
	(*PrepareWITAuthorityResponse)(nil),         // 27: spire.api.server.localauthority.v1.PrepareWITAuthorityResponse
	(*ActivateWITAuthorityRequest)(nil),         // 28: spire.api.server.localauthority.v1.ActivateWITAuthorityRequest
	(*ActivateWITAuthorityResponse)(nil),        // 29: spire.api.server.localauthority.v1.ActivateWITAuthorityResponse
	(*TaintWITAuthorityRequest)(nil),            // 30: spire.api.server.localauthority.v1.TaintWITAuthorityRequest
	(*TaintWITAuthorityResponse)(nil),           // 31: spire.api.server.localauthority.v1.TaintWITAuthorityResponse
	(*RevokeWITAuthorityRequest)(nil),           // 32: spire.api.server.localauthority.v1.RevokeWITAuthorityRequest
	(*RevokeWITAuthorityResponse)(nil),          // 33: spire.api.server.localauthority.v1.RevokeWITAuthorityResponse
	(*AuthorityState)(nil),                      // 34: spire.api.server.localauthority.v1.AuthorityState
}
var file_spire_api_server_localauthority_v1_localauthority_proto_depIdxs = []int32{
	34, // 0: spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse.active:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 1: spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse.prepared:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 2: spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse.old:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 3: spire.api.server.localauthority.v1.PrepareJWTAuthorityResponse.prepared_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 4: spire.api.server.localauthority.v1.ActivateJWTAuthorityResponse.activated_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 5: spire.api.server.localauthority.v1.TaintJWTAuthorityResponse.tainted_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 6: spire.api.server.localauthority.v1.RevokeJWTAuthorityResponse.revoked_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 7: spire.api.server.localauthority.v1.GetX509AuthorityStateResponse.active:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 8: spire.api.server.localauthority.v1.GetX509AuthorityStateResponse.prepared:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 9: spire.api.server.localauthority.v1.GetX509AuthorityStateResponse.old:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 10: spire.api.server.localauthority.v1.PrepareX509AuthorityResponse.prepared_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 11: spire.api.server.localauthority.v1.ActivateX509AuthorityResponse.activated_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 12: spire.api.server.localauthority.v1.TaintX509AuthorityResponse.tainted_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 13: spire.api.server.localauthority.v1.RevokeX509AuthorityResponse.revoked_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 14: spire.api.server.localauthority.v1.GetWITAuthorityStateResponse.active:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 15: spire.api.server.localauthority.v1.GetWITAuthorityStateResponse.prepared:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 16: spire.api.server.localauthority.v1.GetWITAuthorityStateResponse.old:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 17: spire.api.server.localauthority.v1.PrepareWITAuthorityResponse.prepared_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 18: spire.api.server.localauthority.v1.ActivateWITAuthorityResponse.activated_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 19: spire.api.server.localauthority.v1.TaintWITAuthorityResponse.tainted_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	34, // 20: spire.api.server.localauthority.v1.RevokeWITAuthorityResponse.revoked_authority:type_name -> spire.api.server.localauthority.v1.AuthorityState
	0,  // 21: spire.api.server.localauthority.v1.LocalAuthority.GetJWTAuthorityState:input_type -> spire.api.server.localauthority.v1.GetJWTAuthorityStateRequest
	2,  // 22: spire.api.server.localauthority.v1.LocalAuthority.PrepareJWTAuthority:input_type -> spire.api.server.localauthority.v1.PrepareJWTAuthorityRequest
	4,  // 23: spire.api.server.localauthority.v1.LocalAuthority.ActivateJWTAuthority:input_type -> spire.api.server.localauthority.v1.ActivateJWTAuthorityRequest
	6,  // 24: spire.api.server.localauthority.v1.LocalAuthority.TaintJWTAuthority:input_type -> spire.api.server.localauthority.v1.TaintJWTAuthorityRequest
	8,  // 25: spire.api.server.localauthority.v1.LocalAuthority.RevokeJWTAuthority:input_type -> spire.api.server.localauthority.v1.RevokeJWTAuthorityRequest
	10, // 26: spire.api.server.localauthority.v1.LocalAuthority.GetX509AuthorityState:input_type -> spire.api.server.localauthority.v1.GetX509AuthorityStateRequest
	12, // 27: spire.api.server.localauthority.v1.LocalAuthority.PrepareX509Authority:input_type -> spire.api.server.localauthority.v1.PrepareX509AuthorityRequest
	14, // 28: spire.api.server.localauthority.v1.LocalAuthority.ActivateX509Authority:input_type -> spire.api.server.localauthority.v1.ActivateX509AuthorityRequest
	16, // 29: spire.api.server.localauthority.v1.LocalAuthority.TaintX509Authority:input_type -> spire.api.server.localauthority.v1.TaintX509AuthorityRequest
	18, // 30: spire.api.server.localauthority.v1.LocalAuthority.TaintX509UpstreamAuthority:input_type -> spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityRequest
	22, // 31: spire.api.server.localauthority.v1.LocalAuthority.RevokeX509Authority:input_type -> spire.api.server.localauthority.v1.RevokeX509AuthorityRequest
	20, // 32: spire.api.server.localauthority.v1.LocalAuthority.RevokeX509UpstreamAuthority:input_type -> spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityRequest
	24, // 33: spire.api.server.localauthority.v1.LocalAuthority.GetWITAuthorityState:input_type -> spire.api.server.localauthority.v1.GetWITAuthorityStateRequest
	26, // 34: spire.api.server.localauthority.v1.LocalAuthority.PrepareWITAuthority:input_type -> spire.api.server.localauthority.v1.PrepareWITAuthorityRequest
	28, // 35: spire.api.server.localauthority.v1.LocalAuthority.ActivateWITAuthority:input_type -> spire.api.server.localauthority.v1.ActivateWITAuthorityRequest
	30, // 36: spire.api.server.localauthority.v1.LocalAuthority.TaintWITAuthority:input_type -> spire.api.server.localauthority.v1.TaintWITAuthorityRequest
	32, // 37: spire.api.server.localauthority.v1.LocalAuthority.RevokeWITAuthority:input_type -> spire.api.server.localauthority.v1.RevokeWITAuthorityRequest
	1,  // 38: spire.api.server.localauthority.v1.LocalAuthority.GetJWTAuthorityState:output_type -> spire.api.server.localauthority.v1.GetJWTAuthorityStateResponse
	3,  // 39: spire.api.server.localauthority.v1.LocalAuthority.PrepareJWTAuthority:output_type -> spire.api.server.localauthority.v1.PrepareJWTAuthorityResponse
	5,  // 40: spire.api.server.localauthority.v1.LocalAuthority.ActivateJWTAuthority:output_type -> spire.api.server.localauthority.v1.ActivateJWTAuthorityResponse
	7,  // 41: spire.api.server.localauthority.v1.LocalAuthority.TaintJWTAuthority:output_type -> spire.api.server.localauthority.v1.TaintJWTAuthorityResponse
	9,  // 42: spire.api.server.localauthority.v1.LocalAuthority.RevokeJWTAuthority:output_type -> spire.api.server.localauthority.v1.RevokeJWTAuthorityResponse
	11, // 43: spire.api.server.localauthority.v1.LocalAuthority.GetX509AuthorityState:output_type -> spire.api.server.localauthority.v1.GetX509AuthorityStateResponse
	13, // 44: spire.api.server.localauthority.v1.LocalAuthority.PrepareX509Authority:output_type -> spire.api.server.localauthority.v1.PrepareX509AuthorityResponse
	15, // 45: spire.api.server.localauthority.v1.LocalAuthority.ActivateX509Authority:output_type -> spire.api.server.localauthority.v1.ActivateX509AuthorityResponse
	17, // 46: spire.api.server.localauthority.v1.LocalAuthority.TaintX509Authority:output_type -> spire.api.server.localauthority.v1.TaintX509AuthorityResponse
	19, // 47: spire.api.server.localauthority.v1.LocalAuthority.TaintX509UpstreamAuthority:output_type -> spire.api.server.localauthority.v1.TaintX509UpstreamAuthorityResponse
	23, // 48: spire.api.server.localauthority.v1.LocalAuthority.RevokeX509Authority:output_type -> spire.api.server.localauthority.v1.RevokeX509AuthorityResponse
	21, // 49: spire.api.server.localauthority.v1.LocalAuthority.RevokeX509UpstreamAuthority:output_type -> spire.api.server.localauthority.v1.RevokeX509UpstreamAuthorityResponse
	25, // 50: spire.api.server.localauthority.v1.LocalAuthority.GetWITAuthorityState:output_type -> spire.api.server.localauthority.v1.GetWITAuthorityStateResponse
	27, // 51: spire.api.server.localauthority.v1.LocalAuthority.PrepareWITAuthority:output_type -> spire.api.server.localauthority.v1.PrepareWITAuthorityResponse
	29, // 52: spire.api.server.localauthority.v1.LocalAuthority.ActivateWITAuthority:output_type -> spire.api.server.localauthority.v1.ActivateWITAuthorityResponse
	31, // 53: spire.api.server.localauthority.v1.LocalAuthority.TaintWITAuthority:output_type -> spire.api.server.localauthority.v1.TaintWITAuthorityResponse
	33, // 54: spire.api.server.localauthority.v1.LocalAuthority.RevokeWITAuthority:output_type -> spire.api.server.localauthority.v1.RevokeWITAuthorityResponse
	38, // [38:55] is the sub-list for method output_type
	21, // [21:38] is the sub-list for method input_type
	21, // [21:21] is the sub-list for extension type_name
	21, // [21:21] is the sub-list for extension extendee
	0,  // [0:21] is the sub-list for field type_name
}

func init() { file_spire_api_server_localauthority_v1_localauthority_proto_init() }
func file_spire_api_server_localauthority_v1_localauthority_proto_init() {
	if File_spire_api_server_localauthority_v1_localauthority_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_spire_api_server_localauthority_v1_localauthority_proto_rawDesc), len(file_spire_api_server_localauthority_v1_localauthority_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   35,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_spire_api_server_localauthority_v1_localauthority_proto_goTypes,
		DependencyIndexes: file_spire_api_server_localauthority_v1_localauthority_proto_depIdxs,
		MessageInfos:      file_spire_api_server_localauthority_v1_localauthority_proto_msgTypes,
	}.Build()
	File_spire_api_server_localauthority_v1_localauthority_proto = out.File
	file_spire_api_server_localauthority_v1_localauthority_proto_goTypes = nil
	file_spire_api_server_localauthority_v1_localauthority_proto_depIdxs = nil
}
